@@ -225,8 +225,8 @@ def _extract_imports(lean_file_path: Path) -> list[str]:
 
                 import_path = import_split[1].strip()
 
-                # Skip Mathlib library imports - these are handled automatically
-                if import_path.startswith("Mathlib"):
+                standard_libs = ["Mathlib", "Lean", "Std"]
+                if any(import_path.startswith(lib) for lib in standard_libs):
                     logger.debug(f"Skipping standard library import: {import_path}")
                     continue
 
@@ -280,13 +280,16 @@ def _resolve_import_to_file_path(
 
     attempted_paths: list[Path] = []
 
-    # Prevent self-imports
-    if (
-        source_file_path.stem == import_path
-        or source_file_path.stem == import_path.replace(".", "/").split("/")[-1]
-    ):
-        logger.debug(f"Skipping self-import: {import_path}")
-        return None
+    try:
+        relative_source = source_file_path.relative_to(project_root)
+        source_module_path = str(relative_source.with_suffix("")).replace("/", ".")
+        
+        if source_module_path == import_path:
+            logger.debug(f"Skipping self-import: {import_path}")
+            return None
+    except ValueError:
+        # source_file_path is not relative to project_root, so it can't be a self-import
+        pass
 
     module_path = import_path.replace(".", "/") + ".lean"
 
